import { GroupCandidateService } from './../../services/group-candidate.service';
import { Router, ActivatedRoute } from '@angular/router';
import { GroupService } from './../../services/group.service';
import { Component, OnInit } from '@angular/core';
import { Group } from '../../interfaces/group.interface';
import { Observable } from 'rxjs';
import { User } from 'src/app/user/interfaces/user.interface';

@Component({
  selector: 'app-group-edit',
  templateUrl: './group-edit.component.html',
  styleUrls: ['./group-edit.component.scss']
})
export class GroupEditComponent implements OnInit {

  group$: Observable<Group>;
  groupCandidates$: Observable<User[]>;
  currentUserId: string;
  groupId: number;

  constructor(private groupService: GroupService,
              private groupCandidateService: GroupCandidateService,
              private activatedRoute: ActivatedRoute,
              private router: Router) { }

  ngOnInit(): void {
    this.currentUserId = localStorage.getItem('userId');
    this.groupId = this.activatedRoute.snapshot.params.groupId;
    this.group$ = this.groupService.getGroup(this.groupId);
    this.groupCandidates$ = this.groupCandidateService.getList(this.groupId);
  }

  onBackToGroupList(): void {
    this.router.navigateByUrl('/group');
  }

  onDelete(): void {
    this.groupService.delete(this.groupId).subscribe(() => {
      this.router.navigateByUrl('/group');
    });
  }

  onLeaveGroup(): void {
    this.groupService.leaveGroup(this.groupId, localStorage.getItem('userId')).subscribe(() => {
      this.router.navigateByUrl('/group');
    });
  }

  onCandidateAccept(userId: string) {
    this.groupCandidateService.accept(this.groupId, userId).subscribe(() => {
      this.group$ = this.groupService.getGroup(this.groupId);
      this.groupCandidates$ = this.groupCandidateService.getList(this.groupId);
    });
  }

  onCandidateDecline(userId: string) {
    this.groupCandidateService.decline(this.groupId, userId).subscribe(() => {
      this.groupCandidates$ = this.groupCandidateService.getList(this.groupId);
    });
  }

  onDeleteUser(userId: string) {
    this.groupService.leaveGroup(this.groupId, userId).subscribe(() => {
      this.group$ = this.groupService.getGroup(this.groupId);
    });
  }

}
