import { GroupCandidateService } from './../../services/group-candidate.service';
import { Router } from '@angular/router';
import { GroupService } from './../../services/group.service';
import { Component, OnInit } from '@angular/core';
import { Group } from '../../interfaces/group.interface';
import { Observable } from 'rxjs';

@Component({
  selector: 'app-group-main',
  templateUrl: './group-main.component.html',
  styleUrls: ['./group-main.component.scss']
})
export class GroupMainComponent implements OnInit {

  userGroups$: Observable<Group[]>;
  allGroups$: Observable<Group[]>;

  constructor(private groupService: GroupService,
              private groupCandidateService: GroupCandidateService,
              private router: Router) { }

  ngOnInit(): void {
    this.userGroups$ = this.groupService.getCurrentUserGroups();
    this.allGroups$ = this.groupService.getAllGroups();
  }

  onAddNew(): void {
    this.router.navigateByUrl('/group/add-new');
  }

  onShow(groupId: number) {
    this.router.navigateByUrl(`/group/edit/${groupId}`);
  }

  onJoinRequest(groupId: number) {
    this.groupCandidateService.joinRequest(groupId).subscribe(() => {
      alert('request sent');
    });
  }

}
