import { Observable } from 'rxjs';
import { Injectable } from '@angular/core';
import { environment } from 'src/environments/environment';
import { Group } from '../interfaces/group.interface';
import { HttpClient } from '@angular/common/http';
import { GroupSaveModel } from '../interfaces/group-save-model.interface';

@Injectable({
  providedIn: 'root'
})
export class GroupService {

  constructor(private http: HttpClient) { }

  add(group: GroupSaveModel): Observable<void> {
    return this.http.post<void>(environment.host + environment.apiEndpoints.groups.add, group);
  }

  getAllGroups(): Observable<Group[]> {
    return this.http.get<Group[]>(environment.host + environment.apiEndpoints.groups.getAll);
  }

  getGroup(groupId: number): Observable<Group> {
    return this.http.get<Group>(`${environment.host}${environment.apiEndpoints.groups.getById}/${groupId}`);
  }

  getCurrentUserGroups(): Observable<Group[]> {
    return this.http.get<Group[]>(`${environment.host}${environment.apiEndpoints.groups.getCurrentUserGroups}/${localStorage.getItem('userId')}`);
  }

  leaveGroup(groupId: number, userId: string): Observable<void> {
    return this.http.get<void>(`${environment.host}${environment.apiEndpoints.groups.leave}/${groupId}/${userId}`);
  }

  delete(groupId: number): Observable<void> {
    return this.http.delete<void>(`${environment.host}${environment.apiEndpoints.groups.delete}/${groupId}`);
  }

}
