import { SubjectDeleteRequestService } from './../../services/subject-delete-request.service';
import { Component, Input, OnInit, ViewEncapsulation } from '@angular/core';
import { Observable } from 'rxjs';
import { Subject } from '../../interfaces/subject.interface';
import { SubjectService } from '../../services/subject.service';
import { SubjectDeleteRequest } from '../../interfaces/subject-delete-request.interface';
import { Router } from '@angular/router';

@Component({
  selector: 'app-subject-main',
  templateUrl: './subject-main.component.html',
  styleUrls: ['./subject-main.component.scss']
})
export class SubjectMainComponent implements OnInit {

  @Input() groupId: number;
  @Input() adminId: string;
  userId: string;
  subjects$: Observable<Subject[]>;
  subjectDeleteRequests$: Observable<SubjectDeleteRequest[]>;

  constructor(private router: Router,
              private subjectService: SubjectService,
              private subjectDeleteRequestService: SubjectDeleteRequestService) { }

  ngOnInit(): void {
    this.userId = localStorage.getItem('userId');
    this.subjects$ = this.subjectService.getListByGroupId(Number(this.groupId));
    this.subjectDeleteRequests$ = this.subjectDeleteRequestService.getListByGroupId(this.groupId);
  }

  onAddNewSubject(): void {
    this.router.navigateByUrl('/subject/new-subject/' + this.groupId);
  }

  onApproveDeletion(deletionRequestId: number): void {
    this.subjectDeleteRequestService.approveDeletion(deletionRequestId).subscribe(() => {
      this.subjects$ = this.subjectService.getListByGroupId(this.groupId);
      this.subjectDeleteRequests$ = this.subjectDeleteRequestService.getListByGroupId(this.groupId);
      alert('Deletion approved');
    });
  }

  onAddDeleteRequest(id: number): void {
    this.subjectDeleteRequestService.add(id).subscribe(() => {
      this.subjectDeleteRequests$ = this.subjectDeleteRequestService.getListByGroupId(this.groupId);
      alert('Delete request sent');
    });
  }

  onCancelDeletion(deletionRequestId: number): void {
    this.subjectDeleteRequestService.cancelDeletion(deletionRequestId).subscribe(() => {
      this.subjectDeleteRequests$ = this.subjectDeleteRequestService.getListByGroupId(this.groupId);
      alert('Deletion canceled');
    });
  }

  onDeleteSubject(id: number): void {
    this.subjectService.delete(id).subscribe(() => {
      this.subjects$ = this.subjectService.getListByGroupId(this.groupId);
      alert('success');
    });
  }

  onEditSubject(id: number): void {
    this.router.navigateByUrl(`subject/edit/${this.groupId}/${id}`);
  }

  onUnlockSubject(id: number): void {
    this.subjectService.unlock(id).subscribe(() => {
      this.subjects$ = this.subjectService.getListByGroupId(this.groupId);
    });
  }

}
