import { environment } from './../../../environments/environment';
import { Subject } from './../interfaces/subject.interface';
import { Injectable } from '@angular/core';
import { HttpClient } from '@angular/common/http';
import { Observable } from 'rxjs';

@Injectable({
  providedIn: 'root'
})
export class SubjectService {

  constructor(private http: HttpClient) { }

  add(subject: Subject): Observable<void> {
    return this.http.post<void>(environment.host + environment.apiEndpoints.subjects.add, subject);
  }

  delete(id: number): Observable<void> {
    return this.http.delete<void>(`${environment.host + environment.apiEndpoints.subjects.delete}/${id}`);
  }

  getById(id: number, userId: string): Observable<Subject> {
    return this.http.get<Subject>(`${environment.host + environment.apiEndpoints.subjects.getById}/${id}/${userId}`);
  }

  getListByGroupId(groupId: number): Observable<Subject[]> {
    return this.http.get<Subject[]>(`${environment.host + environment.apiEndpoints.subjects.getListByGroupId}/${groupId}`);
  }

  update(subject: Subject): Observable<void> {
    return this.http.put<void>(`${environment.host + environment.apiEndpoints.subjects.update}/${subject.id}`, subject);
  }

  unlock(id: number): Observable<void> {
    return this.http.get<void>(`${environment.host + environment.apiEndpoints.subjects.unlock}/${id}`);
  }
}
