import { UserService } from './../../services/user.service';
import { Component, OnInit } from '@angular/core';
import { FormGroup, FormControl, Validators, AbstractControl } from '@angular/forms';
import { Router } from '@angular/router';
import { User } from '../../interfaces/user.interface';

@Component({
  selector: 'app-register',
  templateUrl: './register.component.html',
  styleUrls: ['./register.component.scss']
})
export class RegisterComponent implements OnInit {

  registerForm: FormGroup;

  constructor(private userSerice: UserService,
              private router: Router) { }

  ngOnInit(): void {
    this.registerForm = this.createRegisterForm();
  }


  createRegisterForm(): FormGroup {
    return new FormGroup({
      userName: new FormControl('', Validators.required),
      fullName: new FormControl('', Validators.required),
      passwordForm: new FormGroup({
        password: new FormControl('', Validators.required),
        repeatedPassword: new FormControl('', Validators.required)
      }, this.passwordValidator)
    });
  }

  private passwordValidator(form: AbstractControl): { invalid: boolean } {
    if (form.get('password').value !== form.get('repeatedPassword').value) {
        return {invalid: true};
    }
  }

  onRegisterUser(): void {
    const user: User = {
      userName: this.registerForm.get('userName').value,
      fullName: this.registerForm.get('fullName').value,
      password: this.registerForm.get(['passwordForm', 'password']).value
    };
    this.userSerice.register(user).subscribe(() => {
      this.router.navigateByUrl('/user/login');
    });
  }

}
